@@ -1,6 +1,4 @@
-from __future__ import absolute_import
-
-from .endpoints import ComparisonsEndpoint
+from .endpoints import ComparisonsEndpoint, ExportsEndpoint
 from .transport import RESTClient
 from .utilities.urls import Url
 
@@ -19,6 +17,7 @@ class Client(object):
         self.__client = RESTClient(account_id, auth_token)
         self.__base_url = Url(base_url or PRODUCTION_CLOUD_BASE_URL)
         self.comparisons = ComparisonsEndpoint(self.__client, self.__base_url)
+        self.exports = ExportsEndpoint(self.__client, self.__base_url)
 
     @property
     def account_id(self):
@@ -42,13 +41,17 @@ class Client(object):
 
     @verify_ssl.setter
     def verify_ssl(self, v):
-        # type: (v) -> None
+        # type: (bool) -> None
         self.__client.verify_ssl = v
 
     def __repr__(self):
         # type: () -> str
-        return "Client(account_id={}, auth_token={}, base_url={})".format(
-            repr(self.account_id), repr(self.auth_token), repr(self.base_url)
+        return (
+            "Client("
+            f"account_id={self.account_id!r}, "
+            f"auth_token={self.auth_token!r}, "
+            f"base_url={self.base_url!r}"
+            ")"
         )
 
 
