@@ -1,16 +1,9 @@
-from datetime import datetime
-
-from . import timezone
-
-_unix_epoch = datetime(1970, 1, 1, tzinfo=timezone.utc)
+from datetime import datetime, timezone
 
 
-# A Python 2 compatible method for getting timestamps...
-
-
-def aware_datetime_to_timestamp(dt):
+def aware_datetime_to_timestamp(dt):  # pylint: disable=invalid-name
     # type: (datetime) -> int
-    return int((dt - _unix_epoch).total_seconds())
+    return int(dt.timestamp())
 
 
 def parse_datetime(iso_format_string):
@@ -20,7 +13,7 @@ def parse_datetime(iso_format_string):
             tzinfo=timezone.utc
         )
     except ValueError:
-        # Sometimes the datetime can be missing the milliseconds, in which case the strptime call fails.
+        # Sometimes the datetime can be missing the microseconds
         return datetime.strptime(iso_format_string, "%Y-%m-%dT%H:%M:%SZ").replace(
             tzinfo=timezone.utc
         )
